import requests
import urllib3
from requests import Session
from requests.adapters import HTTPAdapter

DEFAULT_HEADERS = {
    'User-Agent': 'Mozilla/5.0 (Windows NT 6.2; Win64; x64; rv:16.0.1) Gecko/20121011 Firefox/16.0.1'
}


def get_session(retry_time=5, verify=False, proxies=None, headers=None) -> Session:
    """
    获取预配置session.
    :param retry_time: 重试次数.
    :param verify: 是否验证https证书, 默认不验证, 加速爬虫.
    :param proxies: 设置代理服务器.
    :param headers: 默认请求头.
    :return: Session对象.
    """
    if not verify:
        urllib3.disable_warnings()

    s = requests.Session()

    s.mount('http://', HTTPAdapter(max_retries=retry_time))
    s.mount('https://', HTTPAdapter(max_retries=retry_time))

    s.verify = verify

    if proxies:
        s.proxies.update(proxies)

    if not headers:
        headers = DEFAULT_HEADERS

    s.headers = headers

    return s



from datetime import timedelta

import minio


class S3Sign:
    def __init__(self, url, access_key, secret_key, region=''):
        self.url = url
        self.region = region
        self.cred = minio.api.StaticProvider(access_key, secret_key).retrieve()

    def get(self, bucket, path, expires=timedelta(minutes=5)):
        url = minio.api.BaseURL(self.url, self.region).build(
            method='GET',
            region=self.region,
            bucket_name=bucket,
            object_name=path,
        )

        url = minio.api.presign_v4(
            method='GET',
            url=url,
            region=self.region,
            credentials=self.cred,
            date=minio.api.time.utcnow(),
            expires=int(expires.total_seconds()),
        )
        return minio.api.urlunsplit(url)



#!/usr/bin/env python
# coding: utf-8

import setuptools

with open('README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()

setuptools.setup(
    name='licsber',
    version='4.1.0',
    author='Licsber',
    author_email='licsber@gmail.com',
    url='https://www.cnblogs.com/licsber/',
    description=u'个人娱乐工具箱.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=setuptools.find_packages(),
    include_package_data=True,
    install_requires=[
        'pymongo',
        'requests',
        'tqdm',
    ],
    extras_require={
        'all': [
            'opencv-python',
            'paddlepaddle~=2.0',
            'beautifulsoup4',
            'pycryptodome',
            'minio',
            'h5py',
            'matplotlib',
        ],
        'cv': [
            'opencv-python',
            'matplotlib',
        ],
        'wisedu': [
            'opencv-python',
            'pycryptodome',
            'beautifulsoup4',
            'paddlepaddle~=2.0',
        ],
        'datasets': [
            'h5py',
        ],
        's3': [
            'minio',
        ],
    },
    entry_points={
        'console_scripts': [
            'licsber=licsber.shell.hello:licsber',
            'count-dir=licsber.shell.dir_ops:count_dir',
            'flatten-dir=licsber.shell.dir_ops:flatten_dir',
            'empty-dir=licsber.shell.dir_ops:empty_dir',
            'archive=licsber.shell.dir_ops:archive',
            'rename=licsber.shell.dir_ops:rename',
            'save-115=licsber.shell.cloud_drive:save_115_link',
            'save-115-dir=licsber.shell.cloud_drive:save_115_dir',
            'conv=licsber.shell.cloud_drive:conv',
            'memobird=licsber.shell:memobird',
        ],
    },
    classifiers=[
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3 :: Only',
        'Operating System :: OS Independent',
    ],
    license='GPLv3',
)
